@@ -11,7 +11,7 @@ from opensearch_dsl import Document as DSLDocument
 from opensearchpy.helpers import bulk, parallel_bulk
 
 from . import fields
-from .apps import DEDConfig
+from .apps import DODConfig
 from .exceptions import ModelFieldNotMappedError
 from .management.enums import OpensearchAction
 from .search import Search
@@ -45,6 +45,8 @@ model_field_class_to_field_class = {
 
 
 class Document(DSLDocument):
+    """Allow the definition of Opensearch' index using Django `Model`."""
+
     _prepared_fields = []
 
     def __init__(self, **kwargs):
@@ -53,6 +55,7 @@ class Document(DSLDocument):
 
     @classmethod
     def search(cls, using=None, index=None):
+        """Return a `Search` object parametrized with the index' information."""
         return Search(
             using=cls._get_using(using), index=cls._default_index(index), doc_type=[cls], model=cls.django.model
         )
@@ -80,9 +83,15 @@ class Document(DSLDocument):
             unit = "mins"
         return f"{eta} {unit}"
 
-    def get_indexing_queryset(self, verbose: bool = False, filter_: Optional[Q] = None, exclude: Optional[Q] = None,
-                              count: int = None, action: OpensearchAction = OpensearchAction.INDEX,
-                              stdout: io.FileIO = sys.stdout) -> Iterable:
+    def get_indexing_queryset(
+        self,
+        verbose: bool = False,
+        filter_: Optional[Q] = None,
+        exclude: Optional[Q] = None,
+        count: int = None,
+        action: OpensearchAction = OpensearchAction.INDEX,
+        stdout: io.FileIO = sys.stdout,
+    ) -> Iterable:
         """Divide the queryset into chunks."""
         chunk_size = self.django.queryset_pagination
         qs = self.get_queryset(filter_=filter_, exclude=exclude, count=count)
@@ -99,7 +108,7 @@ class Document(DSLDocument):
             if verbose:
                 stdout.write(f"{action} {model}: {round(i / count * 100)}% ({self._eta(start, done, count)})\r")
 
-            for obj in qs[i: i + chunk_size]:
+            for obj in qs[i : i + chunk_size]:
                 done += 1
                 yield obj
 
@@ -114,16 +123,16 @@ class Document(DSLDocument):
         Extracts the preparers from the model and generate a list of callables
         to avoid doing that work on every object instance over.
         """
-        index_fields = getattr(self, '_fields', {})
+        index_fields = getattr(self, "_fields", {})
         preparers = []
         for name, field in iter(index_fields.items()):
-            if not isinstance(field, fields.DEDField):  # pragma: no cover
+            if not isinstance(field, fields.DODField):  # pragma: no cover
                 continue
 
             if not field._path:  # noqa
                 field._path = [name]
 
-            prep_func = getattr(self, 'prepare_%s' % name, None)
+            prep_func = getattr(self, "prepare_%s" % name, None)
             fn = prep_func if prep_func else partial(field.get_value_from_instance)
 
             preparers.append((name, field, fn))
@@ -131,45 +140,32 @@ class Document(DSLDocument):
         return preparers
 
     def prepare(self, instance):
-        """
-        Take a model instance, and turn it into a dict that can be serialized
-        based on the fields defined on this DocType subclass
-        """
-        data = {
-            name: prep_func(instance)
-            for name, field, prep_func in self._prepared_fields
-        }
+        """Generate the opensearch's document from `instance` based on defined fields."""
+        data = {name: prep_func(instance) for name, field, prep_func in self._prepared_fields}
         return data
 
     @classmethod
     def to_field(cls, field_name, model_field):
-        """
-        Returns the opensearch field instance appropriate for the model
-        field class. This is a good place to hook into if you have more complex
-        model field to ES field logic
+        """Return the opensearch field instance mapped to the model field class.
+
+        This is a good place to hook into if you have more complex
+        model field to OS field logic.
         """
         try:
-            return model_field_class_to_field_class[
-                model_field.__class__](attr=field_name)
+            return model_field_class_to_field_class[model_field.__class__](attr=field_name)
         except KeyError:  # pragma: no cover
-            raise ModelFieldNotMappedError(
-                f"Cannot convert model field {field_name} to an Opensearch field!"
-            )
+            raise ModelFieldNotMappedError(f"Cannot convert model field {field_name} to an Opensearch field!")
 
     def bulk(self, actions, **kwargs):
-
+        """Execute given actions in bulk."""
         response = bulk(client=self._get_connection(), actions=actions, **kwargs)
         # send post index signal
-        post_index.send(
-            sender=self.__class__,
-            instance=self,
-            actions=actions,
-            response=response
-        )
+        post_index.send(sender=self.__class__, instance=self, actions=actions, response=response)
         return response
 
     def parallel_bulk(self, actions, **kwargs):
-        kwargs.setdefault('chunk_size', self.django.queryset_pagination)
+        """Parallel version of `bulk`."""
+        kwargs.setdefault("chunk_size", self.django.queryset_pagination)
         bulk_actions = parallel_bulk(client=self._get_connection(), actions=actions, **kwargs)
         # As the `parallel_bulk` is lazy, we need to get it into `deque` to run
         # it instantly.
@@ -181,7 +177,8 @@ class Document(DSLDocument):
 
     @classmethod
     def generate_id(cls, object_instance):
-        """
+        """Generate the opensearch's _id from a Django `Model` instance.
+
         The default behavior is to use the Django object's pk (id) as the
         opensearch index id (_id). If needed, this method can be overloaded
         to change this default behavior.
@@ -190,36 +187,35 @@ class Document(DSLDocument):
 
     def _prepare_action(self, object_instance, action):
         return {
-            '_op_type': action,
-            '_index': self._index._name,  # noqa
-            '_id': self.generate_id(object_instance),
-            '_source' if action != 'update' else 'doc': (
-                self.prepare(object_instance) if action != 'delete' else None
-            ),
+            "_op_type": action,
+            "_index": self._index._name,  # noqa
+            "_id": self.generate_id(object_instance),
+            "_source" if action != "update" else "doc": (self.prepare(object_instance) if action != "delete" else None),
         }
 
     def _get_actions(self, object_list, action):
         for object_instance in object_list:
-            if action == 'delete' or self.should_index_object(object_instance):
+            if action == "delete" or self.should_index_object(object_instance):
                 yield self._prepare_action(object_instance, action)
 
     def _bulk(self, *args, parallel=False, **kwargs):
-        """Helper for switching between normal and parallel bulk operation"""
+        """Helper for switching between normal and parallel bulk operation."""
         if parallel:
             return self.parallel_bulk(*args, **kwargs)
         return self.bulk(*args, **kwargs)
 
     def should_index_object(self, obj):
-        """
-        Overwriting this method and returning a boolean value
-        should determine whether the object should be indexed.
+        """Whether given object should be indexed.
+
+        Overwriting this method and returning a boolean value should determine
+        whether the object should be indexed.
         """
         return True
 
     def update(self, thing, action, *args, refresh=None, **kwargs):  # noqa
-        """Update document in ES for a model, iterable of models or queryset."""
+        """Update document in OS for a model, iterable of models or queryset."""
         if refresh is None:
-            refresh = getattr(self.Index, "auto_refresh", DEDConfig.auto_refresh_enabled())
+            refresh = getattr(self.Index, "auto_refresh", DODConfig.auto_refresh_enabled())
 
         if isinstance(thing, models.Model):
             object_list = [thing]
