@@ -4,7 +4,7 @@ from copy import deepcopy
 from django.core.exceptions import ImproperlyConfigured
 from opensearch_dsl import AttrDict
 
-from .apps import DEDConfig
+from .apps import DODConfig
 from .exceptions import RedeclaredFieldError
 
 
@@ -27,23 +27,24 @@ class DocumentRegistry:
         self._indices[index].add(doc_class)
 
     def register_document(self, document):
-        django_meta = getattr(document, 'Django')
+        """Register given document within the registry."""
+        django_meta = getattr(document, "Django")
         # Raise error if Django class can not be found
         if not django_meta:  # pragma: no cover
             message = f"You must declare the Django class inside {document.__name__}"
             raise ImproperlyConfigured(message)
 
         # Keep all django related attribute in a django_attr AttrDict
-        django_attr = AttrDict({
-            'model': getattr(document.Django, 'model'),
-            'queryset_pagination': getattr(
-                document.Django, 'queryset_pagination', DEDConfig.default_queryset_pagination()
-            ),
-            'ignore_signals': getattr(django_meta, 'ignore_signals', False),
-            'auto_refresh': getattr(
-                django_meta, 'auto_refresh', DEDConfig.auto_refresh_enabled()
-            ),
-        })
+        django_attr = AttrDict(
+            {
+                "model": getattr(document.Django, "model"),
+                "queryset_pagination": getattr(
+                    document.Django, "queryset_pagination", DODConfig.default_queryset_pagination()
+                ),
+                "ignore_signals": getattr(django_meta, "ignore_signals", False),
+                "auto_refresh": getattr(django_meta, "auto_refresh", DODConfig.auto_refresh_enabled()),
+            }
+        )
         if not django_attr.model:  # pragma: no cover
             raise ImproperlyConfigured("You must specify the django model")
 
@@ -63,14 +64,14 @@ class DocumentRegistry:
             document._doc_type.mapping.field(field_name, field_instance)  # noqa
 
         # Add django attribute with all the django attribute
-        setattr(document, 'django', django_attr)
+        setattr(document, "django", django_attr)
 
         # Set the fields of the mappings
         fields = document._doc_type.mapping.properties.properties.to_dict()  # noqa
-        setattr(document, '_fields', fields)
+        setattr(document, "_fields", fields)
 
         # Update settings of the document index
-        default_index_settings = deepcopy(DEDConfig.default_index_settings())
+        default_index_settings = deepcopy(DODConfig.default_index_settings())
         document._index.settings(**{**default_index_settings, **document._index._settings})  # noqa
 
         # Register the document and index class to our registry
@@ -78,12 +79,13 @@ class DocumentRegistry:
 
         return document
 
-    def update(self, instance, action='index', **kwargs):
+    def update(self, instance, action="index", **kwargs):
+        """Update all the opensearch documents attached to this model.
+
+        Only update if settings' `OPENSEARCH_DSL_AUTOSYNC` is `True` and
+        `Document'`s `ignore_signals` is `False`.
         """
-        Update all the elasticsearch documents attached to this model (if their
-        ignore_signals flag allows it)
-        """
-        if not DEDConfig.autosync_enabled():
+        if not DODConfig.autosync_enabled():
             return
 
         if instance.__class__ in self._models:
@@ -92,11 +94,12 @@ class DocumentRegistry:
                     doc().update(instance, action, **kwargs)
 
     def delete(self, instance, **kwargs):
+        """Delete all the opensearch documents attached to this model.
+
+        Only delete if settings' `OPENSEARCH_DSL_AUTOSYNC` is `True` and
+        `Document'`s `ignore_signals` is `False`.
         """
-        Delete all the elasticsearch documents attached to this model (if their
-        ignore_signals flag allows it)
-        """
-        self.update(instance, action='delete', **kwargs)
+        self.update(instance, action="delete", **kwargs)
 
     def get_indices(self):
         """Get all indices in the registry."""
