@@ -6,8 +6,10 @@ from opensearch_dsl.connections import connections
 
 
 class Search(DSLSearch):
+    """Subclass of `opensearch_dsl.Search` with some utility methods."""
+
     def __init__(self, **kwargs):
-        self._model = kwargs.pop('model', None)
+        self._model = kwargs.pop("model", None)
         super(Search, self).__init__(**kwargs)
 
     def _clone(self):
@@ -16,16 +18,13 @@ class Search(DSLSearch):
         return s
 
     def to_queryset(self, keep_order=False):
-        """
-        This method return a django queryset from the an opensearch result.
-        It cost a query to the sql db.
-        """
+        """Return a django queryset corresponding to the opensearch result."""
         s = self
 
         # Do not query again if the search result is already cached
-        if not hasattr(self, '_response'):
+        if not hasattr(self, "_response"):
             # We only need the meta fields with the models ids
-            s = self.source(excludes=['*'])
+            s = self.source(excludes=["*"])
             s = s.execute()
 
         pks = [result.meta.id for result in s]
@@ -33,15 +32,16 @@ class Search(DSLSearch):
         qs = self._model.objects.filter(pk__in=pks)
 
         if keep_order:
-            preserved_order = Case(
-                *[When(pk=pk, then=pos) for pos, pk in enumerate(pks)],
-                output_field=IntegerField()
-            )
+            preserved_order = Case(*[When(pk=pk, then=pos) for pos, pk in enumerate(pks)], output_field=IntegerField())
             qs = qs.order_by(preserved_order)
 
         return qs
 
     def validate(self, explain=False):
+        """Expose `opensearchpy` validate API.
+
+        It can validate a query syntax without executing it.
+        """
         response = connections.get_connection().indices.validate_query(
             body=self.to_dict(), index=self._index[0], explain=True
         )
